asr.test.mocks.gpaw.berryphase
==============================

.. automodule:: asr.test.mocks.gpaw.berryphase

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_berry_phases
   
   

   
   
   

   
   
   